@@ -21,9 +21,8 @@ def is_valid_version_arg(increment_version):
 
 
 def write_zip(zip, fp, root, name):
-    absname = os.path.abspath(os.path.join(root, name))
-    arcname = f"{fp.split('/')[-1]}/{name}"
-    zip.write(absname, arcname)
+    path = os.path.abspath(os.path.join(root, name))
+    zip.write(absname, os.path.basename(path))
 
 
 def do_pack(fp, src, target, ignore_paths=None):
